@@ -6,23 +6,23 @@ use thiserror::Error;
 /// These errors signify a held error or an error transforming
 /// a [crate::MessageTransport] into another type.
 pub enum TransportError {
-  /// Error to proxy rmp_serde encoding errors.
-  #[error("Failed to serialize payload: {0}")]
+  /// Error to proxy codec errors.
+  #[error("Serialization error: {0}")]
   SerializationError(String),
 
-  /// Error to proxy rmp_serde decoding errors.
-  #[error("Failed to deserialize payload: {0}")]
+  /// Error to proxy decoding errors.
+  #[error("Deserialization error: {0}")]
   DeserializationError(String),
 
   /// Error used when a payload is invalid or invalidated.
   #[error("Invalid payload")]
   Invalid,
 
-  /// Error from the payload.
+  /// Error from the actual payload.
   #[error("{0}")]
   Error(String),
 
-  /// Exception from the payload.
+  /// Exception from the actual payload.
   #[error("{0}")]
   Exception(String),
 
